@@ -10,8 +10,10 @@
       {"DOM_INT"               ,0, _ZINT, _INT_TYPE, T_TYPE_ID},
       {"DOM_LIST"              ,0, _VECT, _INT_TYPE, T_TYPE_ID},
       {"DOM_LONGFLOAT"                ,0, _REAL, _INT_TYPE, T_TYPE_ID},
+      {"DOM_MAP"               ,0, _MAP, _INT_TYPE, T_TYPE_ID},
       {"DOM_MATRIX"              ,0, _VECT, _INT_TYPE, T_TYPE_ID},
       {"DOM_RAT"              ,0, _FRAC, _INT_TYPE, T_TYPE_ID},
+      {"DOM_SERIES"               ,0, _SPOL1, _INT_TYPE, T_TYPE_ID},
       {"DOM_SPECIALFLOAT"                  ,0,  _FLOAT_, _INT_TYPE, T_TYPE_ID},
       {"DOM_STRING"                ,0, _STRNG, _INT_TYPE, T_TYPE_ID},
       {"DOM_SYMBOLIC"              ,0, _SYMB, _INT_TYPE, T_TYPE_ID},
@@ -92,6 +94,7 @@
       {"default",1,0,0,T_DEFAULT},
       {"dnewton_solver"         ,1, _DNEWTON_SOLVER, _INT_SOLVER,T_NUMBER},
       {"dot_line"         ,1, _DOT_LINE, _INT_COLOR ,T_NUMBER},
+      {"double"               ,0, _DOUBLE_, _INT_TYPE, T_TYPE_ID},
       {"downto",0,-1,0,T_TO},
       {"elif",0,0,0,T_ELIF},
       {"else",0,0,0,T_ELSE},
@@ -122,6 +125,7 @@
       {"epaisseur_point_8"         ,1, _POINT_WIDTH_8 , _INT_COLOR ,T_NUMBER},
       {"esac",0,0,0,T_ENDCASE},
       {"expln"         ,1,_EXPLN , _INT_MAPLECONVERSION ,T_NUMBER},
+      {"expression"         ,0, _SYMBOL, _INT_TYPE ,T_TYPE_ID},
       {"faddeev"         ,1, _FADEEV, _INT_SOLVER,T_NUMBER},
       {"fadeev"         ,1, _FADEEV, _INT_SOLVER,T_NUMBER},
       {"false",1,0,_INT_BOOLEAN,T_NUMBER},
@@ -139,7 +143,7 @@
       {"fsi",0,4,0,T_BLOC_END},
       {"ftantque",0,8,0,T_BLOC_END},
       {"fullparfrac"         ,1,_FULLPARFRAC , _INT_MAPLECONVERSION ,T_NUMBER},
-      {"func",0,0,0,TI_PRGM},
+      {"func"                ,0, _FUNC, _INT_TYPE, T_TYPE_ID},
       {"function",0,0,0,T_PROC},
       {"gauss15"         ,1, _GAUSS15, _INT_SOLVER,T_NUMBER},
       {"gl_ambient"       ,1,_GL_AMBIENT , _INT_PLOT ,T_NUMBER},
@@ -216,6 +220,7 @@
       {"hybridj_solver"         ,1, _HYBRIDJ_SOLVER, _INT_SOLVER,T_NUMBER},
       {"hybrids_solver"         ,1, _HYBRIDS_SOLVER, _INT_SOLVER,T_NUMBER},
       {"hybridsj_solver"         ,1, _HYBRIDSJ_SOLVER, _INT_SOLVER,T_NUMBER},
+      {"identifier"            ,0, _IDNT, _INT_TYPE, T_TYPE_ID},
       {"in",0,0,0,T_IN},
       {"integer"               ,0, _ZINT, _INT_TYPE, T_TYPE_ID},
       {"intersect",0,0,0,T_INTERSECT},
